/*
 * Copyright 2008-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bson.codecs;

import org.bson.BsonReader;
import org.bson.BsonWriter;
import org.bson.types.Decimal128;

/**
 * Encodes and decodes {@code Decimal128} objects.
 *
 * @since 3.4
 */
public final class Decimal128Codec implements Codec<Decimal128> {
    @Override
    public Decimal128 decode(final BsonReader reader, final DecoderContext decoderContext) {
        return reader.readDecimal128();
    }

    @Override
    public void encode(final BsonWriter writer, final Decimal128 value, final EncoderContext encoderContext) {
        writer.writeDecimal128(value);
    }

    @Override
    public Class<Decimal128> getEncoderClass() {
        return Decimal128.class;
    }
}
